skiptools.make_repeated_skips_from_time_signatures
==================================================

.. autofunction:: abjad.tools.skiptools.make_repeated_skips_from_time_signatures.make_repeated_skips_from_time_signatures
